<?php
$basico_menu_section = array();

$basico_menu_option = array();

/**
 * Basico Theme Option Page 
 * 
 * @since Basico 1.0
 */
function basico_theme_menu() {
    add_theme_page('Theme Basico Option', 'Theme Basico Options', 'manage_options', 'basico_menu_options', 'basico_theme_page');
}

add_action('admin_menu', 'basico_theme_menu');

function basico_theme_page() {
    ?>
    <div class="section panel">
        <h1>Custom Theme Options</h1>
        <form method="post" enctype="multipart/form-data" action="options.php">
            <?php
            settings_fields('basico_theme_options');

            do_settings_sections('basico_menu_options');
            ?>
            <p class="submit">  
                <input type="submit" class="button-primary" value="<?php _e('Save Changes','basico') ?>" />  
            </p>  

        </form>

        <p>Created by <a href="http://www.nicearma.com">Nicearma</a>.</p>
    </div>
    <?php
}

/**
 * Register the settings to use on the theme options page
 */
add_action('admin_init', 'basico_register_settings');

/**
 * Function to register the settings
 *
 *  @since Basico 1.0
 */
function basico_register_settings() {

    basico_init_array_menu_options();
    
    wp_enqueue_script('media-upload');
    wp_enqueue_script('thickbox');
    wp_enqueue_script('basico_upload_media', get_template_directory_uri() . '/js/basico-media.js', array('jquery'));
    wp_enqueue_style('thickbox');
    
    global $basico_menu_section;
    global $basico_menu_option;
    
    foreach ($basico_menu_section as $key => $section) {
        add_settings_section($section['id'], $section['name'], $section['callback'], $section['page']);
    }

    foreach ($basico_menu_option as $key => $option) {
        add_settings_field($key, $option['name'], $option['callback'], $basico_menu_section[$option['section']]['page'], $option['section'], $option);
    }

    // Register the settings with Validation callback
    register_setting('basico_theme_options', 'basico_theme_options', 'basico_validate_settings');
}


/**
 * Function to add extra text to display on each section
 * 
 * @since Basico 1.0
 */
function basico_display_section($section) {
    
}

/**
 * 
 * 
 * Function to display the settings on the page
 * 
 * @since Basico 1.0
 */
function basico_display_setting($args) {


    //TODO: change this, I dont like this kind of logic
    extract($args);

    $option_name = 'basico_theme_options';
    $options = basico_get_options();

    if (!array_key_exists($id, $options)) {
        $options[$id] = '';
    }

    switch ($type) {
        case 'text':
            $options[$id] = stripslashes($options[$id]);
            $options[$id] = esc_attr($options[$id]);
            echo '<input class="regular-text' . $class . '" type="text" id="' . $id . '" name="' . $option_name . '[' . $id . ']" value="' . $options[$id] . '" />';
            echo ($desc != '') ? '<br /><span class="description">' . $desc . '</span>' : "";
            break;
        case 'textarea':
            $options[$id] = stripslashes($options[$id]);
            $options[$id] = esc_attr($options[$id]);

            echo '<textarea rows="4" cols="50" class="regular-text' . $class . '"  id="' . $id . '" name="' . $option_name . '[' . $id . ']"  >' . $options[$id] . '</textarea>';
            echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : "";
            break;
        case 'checkboxs':

            foreach ($std as $checkbox) {
                if (!array_key_exists($checkbox['value'], $options)) {
                    $options[$checkbox['value']] = '';
                }
                $options[$checkbox['value']] = stripslashes($options[$checkbox['value']]);
                $options[$checkbox['value']] = esc_attr($options[$checkbox['value']]);

                echo $checkbox['text'] . ' : ' . '<input type="checkbox" name="' . $option_name . '[' . $checkbox['value'] . ']" value="' . $checkbox['value'] . '" ';
                if ($options[$checkbox['value']] == $checkbox['value']) {
                    echo ' checked ';
                }
                echo '/> |';
            }
            break;
        case 'select':

            $options[$id] = stripslashes($options[$id]);
            $options[$id] = esc_attr($options[$id]);
            echo '<select class="" name="' . $option_name . '[' . $id . ']"  id="' . $id . '">';

            foreach ($std as $option) {
                echo '<option value="' . $option['value'] . '"';
                if ($options[$id] == $option['value']) {
                    echo " selected ";
                }
                echo ">" . $option['text'];

                echo "</option>";
            }

            echo '</select>';
            echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : "";
            break;
        case 'upload':
            $options[$id] = stripslashes($options[$id]);
            $options[$id] = esc_attr($options[$id]);
            echo '<input class="regular-text' . $class . '" type="text" id="' . $id . '" name="' . $option_name . '[' . $id . ']" value="' .esc_url( $options[$id]) . '" />';
            echo '<input class="upload_image_button button button-primary" type="button" value="Upload Image" />';
             echo ($desc != '') ? "<br /><span class='description'>$desc</span>" : "";
            break;
    }
}

/**
 * Basico validate function
 * 
 * @global array $basico_menu_option
 * @param type $input
 * @return type
 * @since Basico 1.0
 */
function basico_validate_settings($input) {

    basico_init_array_menu_options();

    global $basico_menu_option;

  
    
    
    foreach ($input as $k => $v) {

        if(empty($basico_menu_option[$k]['validator'])){
            $newinput[$k] =$v;
        }else{
            $newinput[$k] = call_user_func($basico_menu_option[$k]['validator'], $v);
        }
       
    }

    return $newinput;
}

function basico_validate_html($var) {
    return wp_kses($var);
}

function basico_validate_text_simple($var) {
    return esc_html($var);
}

function basico_validate_url($var) {
    return esc_js($var);
}
